pub enum FramingError {
InvalidFrame {
frame_len: usize,
reason: &'static str,
},
PartialFrame {
needed: usize,
remaining: usize,
},
}Expand description
Framing error.
Variants
InvalidFrame
An invalid frame was received.
This generally occurs if the frame is corrupted in some way, due to a bug in how the frame was encoded or sent/received. For example, if a length-delimited frame indicates that the frame is larger than the buffer can handle, it generally indicates that frame was created incorrectly by not respecting the maximum frame length limitations, or the buffer is corrupt and spurious bytes are contributing to a decoded frame length that is nonsensical.
PartialFrame
Failed to read frame due to a partial frame after reaching EOF.
This generally only occurs if the peer closes their connection before sending the entire frame, or if a partial write occurs on a connectionless stream, such as UDP, perhaps due to fragmentation.