pub struct NestedFramer<Inner, Outer> { /* private fields */ }Expand description
A nested framer that extracts inner frames from outer frames.
This framer takes two input framers – the “outer” and “inner” framers – and extracts outer frames, and once an outer frame has been extract, extracts as many inner frames from the outer frame as possible. Callers deal exclusively with the extracted inner frames.
Implementations
Sourceimpl<Inner, Outer> NestedFramer<Inner, Outer>
impl<Inner, Outer> NestedFramer<Inner, Outer>
Sourcepub fn new(inner: Inner, outer: Outer) -> Self
pub fn new(inner: Inner, outer: Outer) -> Self
Creates a new NestedFramer from the given inner and outer framers.
Sourcepub fn take_completed_outer_frames(&mut self) -> usize
pub fn take_completed_outer_frames(&mut self) -> usize
Returns the number of outer frames that have been fully consumed since the last call.